@@ -22,12 +22,11 @@
 from sys import platform
 from typing import Any, Optional
 
-from gi.repository import Adw, Gio, GLib, Gtk, Pango
-
 from cartridges import shared
 from cartridges.game import Game
 from cartridges.game_cover import GameCover
 from cartridges.utils.relative_date import relative_date
+from gi.repository import Adw, Gio, GLib, Gtk, Pango
 
 
 @Gtk.Template(resource_path=shared.PREFIX + "/gtk/window.ui")
@@ -278,6 +277,9 @@ class CartridgesWindow(Adw.ApplicationWindow):
                 "max-children-per-line",
                 Gio.SettingsBindFlags.DEFAULT,
             )
+        else:
+            self.library.set_max_children_per_line(10)
+            self.hidden_library.set_max_children_per_line(10)
 
     def search_changed(self, _widget: Any, hidden: bool) -> None:
         # Refresh search filter on keystroke in search box
@@ -532,4 +534,4 @@ class CartridgesWindow(Adw.ApplicationWindow):
             self.hidden_primary_menu_button.popup()
 
     def on_close_action(self, *_args: Any) -> None:
-        self.close()
+        self.close()
\ No newline at end of file
